==> dcl-5.0.tar.gz: dcl-5.0/src/grph2/uepack/uepqnp.f <==
*-----------------------------------------------------------------------
*     UEPQNP / UEPQID / UEPQCP / UEPQVL / UEPSVL
*-----------------------------------------------------------------------
      SUBROUTINE UEPQNP(NCP)

      CHARACTER CP*(*)

      PARAMETER (NPARA=8)

      INTEGER   IX(NPARA)
      REAL      RX(NPARA)
      LOGICAL   LX(NPARA),LCHREQ,LFIRST
      CHARACTER CPARA(NPARA)*8,CMSG*80

      EQUIVALENCE (IX,RX,LX)

      EXTERNAL  LCHREQ,LENC

      SAVE

      DATA      CPARA( 1)/'LTONE   '/, LX( 1)/.FALSE./
      DATA      CPARA( 2)/'IPAT    '/, IX( 2)/1201/
      DATA      CPARA( 3)/'RLEV    '/, RX( 3)/0.0/
      DATA      CPARA( 4)/'ICYCLE  '/, IX( 4)/2/
      DATA      CPARA( 5)/'NLEV    '/, IX( 5)/12/
      DATA      CPARA( 6)/'ITPAT   '/, IX( 6)/999/
      DATA      CPARA( 7)/'ICOLOR1 '/, IX( 7)/15/
      DATA      CPARA( 8)/'ICOLOR2 '/, IX( 8)/94/

      DATA      LFIRST/.TRUE./


      NCP=NPARA

      RETURN
*-----------------------------------------------------------------------
      ENTRY UEPQID(CP,IDX)

      DO 10 N=1,NPARA
        IF (LCHREQ(CP,CPARA(N))) THEN
          IDX=N
          RETURN
        END IF
   10 CONTINUE
      CMSG='PARAMETER '''//CP(1:LENC(CP))//''' IS NOT DEFINED.'
      CALL MSGDMP('E','UEPQID',CMSG)

      RETURN
*-----------------------------------------------------------------------
      ENTRY UEPQCP(IDX,CP)

      IF (1.LE.IDX .AND. IDX.LE.NPARA) THEN
        CP=CPARA(IDX)
      ELSE
        CALL MSGDMP('E','UEPQCP','IDX IS OUT OF RANGE.')
      END IF

      RETURN
*-----------------------------------------------------------------------
      ENTRY UEPQVL(IDX,IPARA)

      IF (LFIRST) THEN
        CALL RTPGET('UE:',CPARA,IX,NPARA)
        LFIRST=.FALSE.
      END IF

      IF (1.LE.IDX .AND. IDX.LE.NPARA) THEN
        IPARA=IX(IDX)
      ELSE
        CALL MSGDMP('E','UEPQVL','IDX IS OUT OF RANGE.')
      END IF

      RETURN
*-----------------------------------------------------------------------
      ENTRY UEPSVL(IDX,IPARA)

      IF (LFIRST) THEN
        CALL RTPGET('UE:',CPARA,IX,NPARA)
        LFIRST=.FALSE.
      END IF

      IF (1.LE.IDX .AND. IDX.LE.NPARA) THEN
        IX(IDX)=IPARA
      ELSE
        CALL MSGDMP('E','UEPSVL','IDX IS OUT OF RANGE.')
      END IF

      RETURN
      END

==> dcl_5.0.1-3.tar.gz: dcl-5.0.1/src/grph2/uepack/uepqnp.f <==
*-----------------------------------------------------------------------
*     UEPQNP / UEPQID / UEPQCP / UEPQVL / UEPSVL
*-----------------------------------------------------------------------
      SUBROUTINE UEPQNP(NCP)

      CHARACTER CP*(*)

      PARAMETER (NPARA=8)

      INTEGER   IX(NPARA)
      REAL      RX(NPARA)
      LOGICAL   LX(NPARA),LCHREQ,LFIRST
      CHARACTER CPARA(NPARA)*8,CMSG*80

      EQUIVALENCE (IX,RX,LX)

      EXTERNAL  LCHREQ,LENC

      SAVE

      DATA      CPARA( 1)/'LTONE   '/, LX( 1)/.FALSE./
      DATA      CPARA( 2)/'IPAT    '/, IX( 2)/1201/
      DATA      CPARA( 3)/'RLEV    '/, RX( 3)/0.0/
      DATA      CPARA( 4)/'LBOUND  '/, LX( 4)/.TRUE./
      DATA      CPARA( 5)/'NLEV    '/, IX( 5)/12/
      DATA      CPARA( 6)/'ITPAT   '/, IX( 6)/999/
      DATA      CPARA( 7)/'ICOLOR1 '/, IX( 7)/15/
      DATA      CPARA( 8)/'ICOLOR2 '/, IX( 8)/94/

      DATA      LFIRST/.TRUE./


      NCP=NPARA

      RETURN
*-----------------------------------------------------------------------
      ENTRY UEPQID(CP,IDX)

      DO 10 N=1,NPARA
        IF (LCHREQ(CP,CPARA(N))) THEN
          IDX=N
          RETURN
        END IF
   10 CONTINUE
      CMSG='PARAMETER '''//CP(1:LENC(CP))//''' IS NOT DEFINED.'
      CALL MSGDMP('E','UEPQID',CMSG)

      RETURN
*-----------------------------------------------------------------------
      ENTRY UEPQCP(IDX,CP)

      IF (1.LE.IDX .AND. IDX.LE.NPARA) THEN
        CP=CPARA(IDX)
      ELSE
        CALL MSGDMP('E','UEPQCP','IDX IS OUT OF RANGE.')
      END IF

      RETURN
*-----------------------------------------------------------------------
      ENTRY UEPQVL(IDX,IPARA)

      IF (LFIRST) THEN
        CALL RTPGET('UE:',CPARA,IX,NPARA)
        LFIRST=.FALSE.
      END IF

      IF (1.LE.IDX .AND. IDX.LE.NPARA) THEN
        IPARA=IX(IDX)
      ELSE
        CALL MSGDMP('E','UEPQVL','IDX IS OUT OF RANGE.')
      END IF

      RETURN
*-----------------------------------------------------------------------
      ENTRY UEPSVL(IDX,IPARA)

      IF (LFIRST) THEN
        CALL RTPGET('UE:',CPARA,IX,NPARA)
        LFIRST=.FALSE.
      END IF

      IF (1.LE.IDX .AND. IDX.LE.NPARA) THEN
        IX(IDX)=IPARA
      ELSE
        CALL MSGDMP('E','UEPSVL','IDX IS OUT OF RANGE.')
      END IF

      RETURN
      END
